import requests


class WeatherBit:
    def __init__(self, city):
        self.city = city
        self.api_key = "df889d79c28b4bfcafd514b9919bccba"

    def forecast_weather(self, days):
        tmp = {}
        url = f"https://api.weatherbit.io/v2.0/forecast/daily?city={self.city}&days={days}&key={self.api_key}"

        response = requests.get(url)

        if response.status_code == 200:
            data = response.json()

            for forecast in data["data"]:
                date = forecast["valid_date"]
                max_temp = forecast["max_temp"]
                min_temp = forecast["min_temp"]
                condition = forecast["weather"]["description"]

                tmp.update({date: {"max_temp": max_temp,
                                   "min_tem": min_temp,
                                   "condition": condition}})
            return tmp
        return None



import requests


class Shazam:
    def __init__(self):
        self.api_key = "713d8703ecmsh49ae514a91c411ap1fa48fjsn27daa917c41e"

    def complete(self, text):
        url = "https://shazam.p.rapidapi.com/auto-complete"

        headers = {
            "x-rapidapi-key": self.api_key,
            "x-rapidapi-host": "shazam.p.rapidapi.com",
        }

        response = requests.get(url, headers=headers, params={"term": text})

        if response.status_code == 200:
            suggestions = response.json()["hints"]
            return suggestions
        else:
            print(f"Błąd {response.status_code}: {response.text}")



import requests


class Weather:
    def __init__(self, city):
        self.api_key = "433e34d6986e4aceb2f171953231505"
        self.city = city

    def check_weather(self):
        url = f"https://api.weatherapi.com/v1/current.json?key={self.api_key}&q={self.city}"
        response = requests.get(url)

        if response.status_code == 200:
            data = response.json()
            return data['current']['temp_c'], data['current']['condition']['text']
            # print(f"Aktualna temperatura w {self.city}: {data['current']['temp_c']}°C")
            # print(f"Warunki pogodowe: {data['current']['condition']['text']}")
        return None

    def forecast_weather(self, days):
        tmp = {}
        url = f"https://api.weatherapi.com/v1/forecast.json?key={self.api_key}&q={self.city}&days={days}"

        response = requests.get(url)

        if response.status_code == 200:
            data = response.json()

            for forecast in data["forecast"]["forecastday"]:
                date = forecast["date"]
                max_temp = forecast["day"]["maxtemp_c"]
                min_temp = forecast["day"]["mintemp_c"]
                condition = forecast["day"]["condition"]["text"]

                tmp.update({date: {"max_temp": max_temp,
                                   "min_tem": min_temp,
                                   "condition": condition}})
            return tmp
        return None



from setuptools import setup, find_packages

setup(name='dobrepraktyki',
      version='0.1',
      author='Karol Polit',
      author_email='256438@student.pwr.edu.pl',
      packages=find_packages(),
      install_requires=["requests"]
      )
